# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/perpetuals/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.dydxprotocol.perpetuals import perpetual_pb2 as dydxprotocol_dot_perpetuals_dot_perpetual__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#dydxprotocol/perpetuals/query.proto\x12\x17\x64ydxprotocol.perpetuals\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\'dydxprotocol/perpetuals/perpetual.proto\"#\n\x15QueryPerpetualRequest\x12\n\n\x02id\x18\x01 \x01(\r\"U\n\x16QueryPerpetualResponse\x12;\n\tperpetual\x18\x01 \x01(\x0b\x32\".dydxprotocol.perpetuals.PerpetualB\x04\xc8\xde\x1f\x00\"W\n\x19QueryAllPerpetualsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x96\x01\n\x1aQueryAllPerpetualsResponse\x12;\n\tperpetual\x18\x01 \x03(\x0b\x32\".dydxprotocol.perpetuals.PerpetualB\x04\xc8\xde\x1f\x00\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\xce\x02\n\x05Query\x12\x9d\x01\n\tPerpetual\x12..dydxprotocol.perpetuals.QueryPerpetualRequest\x1a/.dydxprotocol.perpetuals.QueryPerpetualResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/dydxprotocol/perpetuals/perpetual/{id}\x12\xa4\x01\n\rAllPerpetuals\x12\x32.dydxprotocol.perpetuals.QueryAllPerpetualsRequest\x1a\x33.dydxprotocol.perpetuals.QueryAllPerpetualsResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/dydxprotocol/perpetuals/perpetualB>Z<github.com/dydxprotocol/v4-chain/protocol/x/perpetuals/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.perpetuals.query_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z<github.com/dydxprotocol/v4-chain/protocol/x/perpetuals/types'
  _QUERYPERPETUALRESPONSE.fields_by_name['perpetual']._options = None
  _QUERYPERPETUALRESPONSE.fields_by_name['perpetual']._serialized_options = b'\310\336\037\000'
  _QUERYALLPERPETUALSRESPONSE.fields_by_name['perpetual']._options = None
  _QUERYALLPERPETUALSRESPONSE.fields_by_name['perpetual']._serialized_options = b'\310\336\037\000'
  _QUERY.methods_by_name['Perpetual']._options = None
  _QUERY.methods_by_name['Perpetual']._serialized_options = b'\202\323\344\223\002)\022\'/dydxprotocol/perpetuals/perpetual/{id}'
  _QUERY.methods_by_name['AllPerpetuals']._options = None
  _QUERY.methods_by_name['AllPerpetuals']._serialized_options = b'\202\323\344\223\002$\022\"/dydxprotocol/perpetuals/perpetual'
  _globals['_QUERYPERPETUALREQUEST']._serialized_start=201
  _globals['_QUERYPERPETUALREQUEST']._serialized_end=236
  _globals['_QUERYPERPETUALRESPONSE']._serialized_start=238
  _globals['_QUERYPERPETUALRESPONSE']._serialized_end=323
  _globals['_QUERYALLPERPETUALSREQUEST']._serialized_start=325
  _globals['_QUERYALLPERPETUALSREQUEST']._serialized_end=412
  _globals['_QUERYALLPERPETUALSRESPONSE']._serialized_start=415
  _globals['_QUERYALLPERPETUALSRESPONSE']._serialized_end=565
  _globals['_QUERY']._serialized_start=568
  _globals['_QUERY']._serialized_end=902
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/capability/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.cosmos.capability.v1beta1 import capability_pb2 as cosmos_dot_capability_dot_v1beta1_dot_capability__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'cosmos/capability/v1beta1/genesis.proto\x12\x19\x63osmos.capability.v1beta1\x1a\x14gogoproto/gogo.proto\x1a*cosmos/capability/v1beta1/capability.proto\x1a\x11\x61mino/amino.proto\"l\n\rGenesisOwners\x12\r\n\x05index\x18\x01 \x01(\x04\x12L\n\x0cindex_owners\x18\x02 \x01(\x0b\x32+.cosmos.capability.v1beta1.CapabilityOwnersB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"b\n\x0cGenesisState\x12\r\n\x05index\x18\x01 \x01(\x04\x12\x43\n\x06owners\x18\x02 \x03(\x0b\x32(.cosmos.capability.v1beta1.GenesisOwnersB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x42\x31Z/github.com/cosmos/cosmos-sdk/x/capability/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.capability.v1beta1.genesis_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/cosmos/cosmos-sdk/x/capability/types'
  _GENESISOWNERS.fields_by_name['index_owners']._options = None
  _GENESISOWNERS.fields_by_name['index_owners']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _GENESISSTATE.fields_by_name['owners']._options = None
  _GENESISSTATE.fields_by_name['owners']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_GENESISOWNERS']._serialized_start=155
  _globals['_GENESISOWNERS']._serialized_end=263
  _globals['_GENESISSTATE']._serialized_start=265
  _globals['_GENESISSTATE']._serialized_end=363
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from v4_proto.dydxprotocol.prices import tx_pb2 as dydxprotocol_dot_prices_dot_tx__pb2


class MsgStub(object):
    """Msg defines the Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.UpdateMarketPrices = channel.unary_unary(
                '/dydxprotocol.prices.Msg/UpdateMarketPrices',
                request_serializer=dydxprotocol_dot_prices_dot_tx__pb2.MsgUpdateMarketPrices.SerializeToString,
                response_deserializer=dydxprotocol_dot_prices_dot_tx__pb2.MsgUpdateMarketPricesResponse.FromString,
                )
        self.CreateOracleMarket = channel.unary_unary(
                '/dydxprotocol.prices.Msg/CreateOracleMarket',
                request_serializer=dydxprotocol_dot_prices_dot_tx__pb2.MsgCreateOracleMarket.SerializeToString,
                response_deserializer=dydxprotocol_dot_prices_dot_tx__pb2.MsgCreateOracleMarketResponse.FromString,
                )
        self.UpdateMarketParam = channel.unary_unary(
                '/dydxprotocol.prices.Msg/UpdateMarketParam',
                request_serializer=dydxprotocol_dot_prices_dot_tx__pb2.MsgUpdateMarketParam.SerializeToString,
                response_deserializer=dydxprotocol_dot_prices_dot_tx__pb2.MsgUpdateMarketParamResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the Msg service.
    """

    def UpdateMarketPrices(self, request, context):
        """UpdateMarketPrices updates the oracle price of a market relative to
        quoteCurrency.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOracleMarket(self, request, context):
        """CreateOracleMarket creates a new oracle market.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateMarketParam(self, request, context):
        """UpdateMarketParams allows governance to update the parameters of an
        oracle market.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'UpdateMarketPrices': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateMarketPrices,
                    request_deserializer=dydxprotocol_dot_prices_dot_tx__pb2.MsgUpdateMarketPrices.FromString,
                    response_serializer=dydxprotocol_dot_prices_dot_tx__pb2.MsgUpdateMarketPricesResponse.SerializeToString,
            ),
            'CreateOracleMarket': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOracleMarket,
                    request_deserializer=dydxprotocol_dot_prices_dot_tx__pb2.MsgCreateOracleMarket.FromString,
                    response_serializer=dydxprotocol_dot_prices_dot_tx__pb2.MsgCreateOracleMarketResponse.SerializeToString,
            ),
            'UpdateMarketParam': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateMarketParam,
                    request_deserializer=dydxprotocol_dot_prices_dot_tx__pb2.MsgUpdateMarketParam.FromString,
                    response_serializer=dydxprotocol_dot_prices_dot_tx__pb2.MsgUpdateMarketParamResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dydxprotocol.prices.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the Msg service.
    """

    @staticmethod
    def UpdateMarketPrices(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.prices.Msg/UpdateMarketPrices',
            dydxprotocol_dot_prices_dot_tx__pb2.MsgUpdateMarketPrices.SerializeToString,
            dydxprotocol_dot_prices_dot_tx__pb2.MsgUpdateMarketPricesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOracleMarket(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.prices.Msg/CreateOracleMarket',
            dydxprotocol_dot_prices_dot_tx__pb2.MsgCreateOracleMarket.SerializeToString,
            dydxprotocol_dot_prices_dot_tx__pb2.MsgCreateOracleMarketResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateMarketParam(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.prices.Msg/UpdateMarketParam',
            dydxprotocol_dot_prices_dot_tx__pb2.MsgUpdateMarketParam.SerializeToString,
            dydxprotocol_dot_prices_dot_tx__pb2.MsgUpdateMarketParamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from v4_proto.dydxprotocol.sending import transfer_pb2 as dydxprotocol_dot_sending_dot_transfer__pb2
from v4_proto.dydxprotocol.sending import tx_pb2 as dydxprotocol_dot_sending_dot_tx__pb2


class MsgStub(object):
    """Msg defines the Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateTransfer = channel.unary_unary(
                '/dydxprotocol.sending.Msg/CreateTransfer',
                request_serializer=dydxprotocol_dot_sending_dot_tx__pb2.MsgCreateTransfer.SerializeToString,
                response_deserializer=dydxprotocol_dot_sending_dot_tx__pb2.MsgCreateTransferResponse.FromString,
                )
        self.DepositToSubaccount = channel.unary_unary(
                '/dydxprotocol.sending.Msg/DepositToSubaccount',
                request_serializer=dydxprotocol_dot_sending_dot_transfer__pb2.MsgDepositToSubaccount.SerializeToString,
                response_deserializer=dydxprotocol_dot_sending_dot_tx__pb2.MsgDepositToSubaccountResponse.FromString,
                )
        self.WithdrawFromSubaccount = channel.unary_unary(
                '/dydxprotocol.sending.Msg/WithdrawFromSubaccount',
                request_serializer=dydxprotocol_dot_sending_dot_transfer__pb2.MsgWithdrawFromSubaccount.SerializeToString,
                response_deserializer=dydxprotocol_dot_sending_dot_tx__pb2.MsgWithdrawFromSubaccountResponse.FromString,
                )
        self.SendFromModuleToAccount = channel.unary_unary(
                '/dydxprotocol.sending.Msg/SendFromModuleToAccount',
                request_serializer=dydxprotocol_dot_sending_dot_transfer__pb2.MsgSendFromModuleToAccount.SerializeToString,
                response_deserializer=dydxprotocol_dot_sending_dot_tx__pb2.MsgSendFromModuleToAccountResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the Msg service.
    """

    def CreateTransfer(self, request, context):
        """CreateTransfer initiates a new transfer between subaccounts.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DepositToSubaccount(self, request, context):
        """DepositToSubaccount initiates a new transfer from an `x/bank` account
        to an `x/subaccounts` subaccount.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WithdrawFromSubaccount(self, request, context):
        """WithdrawFromSubaccount initiates a new transfer from an `x/subaccounts`
        subaccount to an `x/bank` account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendFromModuleToAccount(self, request, context):
        """SendFromModuleToAccount initiates a new transfer from a module to an
        `x/bank` account (should only be executed by governance).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateTransfer': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTransfer,
                    request_deserializer=dydxprotocol_dot_sending_dot_tx__pb2.MsgCreateTransfer.FromString,
                    response_serializer=dydxprotocol_dot_sending_dot_tx__pb2.MsgCreateTransferResponse.SerializeToString,
            ),
            'DepositToSubaccount': grpc.unary_unary_rpc_method_handler(
                    servicer.DepositToSubaccount,
                    request_deserializer=dydxprotocol_dot_sending_dot_transfer__pb2.MsgDepositToSubaccount.FromString,
                    response_serializer=dydxprotocol_dot_sending_dot_tx__pb2.MsgDepositToSubaccountResponse.SerializeToString,
            ),
            'WithdrawFromSubaccount': grpc.unary_unary_rpc_method_handler(
                    servicer.WithdrawFromSubaccount,
                    request_deserializer=dydxprotocol_dot_sending_dot_transfer__pb2.MsgWithdrawFromSubaccount.FromString,
                    response_serializer=dydxprotocol_dot_sending_dot_tx__pb2.MsgWithdrawFromSubaccountResponse.SerializeToString,
            ),
            'SendFromModuleToAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.SendFromModuleToAccount,
                    request_deserializer=dydxprotocol_dot_sending_dot_transfer__pb2.MsgSendFromModuleToAccount.FromString,
                    response_serializer=dydxprotocol_dot_sending_dot_tx__pb2.MsgSendFromModuleToAccountResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dydxprotocol.sending.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the Msg service.
    """

    @staticmethod
    def CreateTransfer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.sending.Msg/CreateTransfer',
            dydxprotocol_dot_sending_dot_tx__pb2.MsgCreateTransfer.SerializeToString,
            dydxprotocol_dot_sending_dot_tx__pb2.MsgCreateTransferResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DepositToSubaccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.sending.Msg/DepositToSubaccount',
            dydxprotocol_dot_sending_dot_transfer__pb2.MsgDepositToSubaccount.SerializeToString,
            dydxprotocol_dot_sending_dot_tx__pb2.MsgDepositToSubaccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WithdrawFromSubaccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.sending.Msg/WithdrawFromSubaccount',
            dydxprotocol_dot_sending_dot_transfer__pb2.MsgWithdrawFromSubaccount.SerializeToString,
            dydxprotocol_dot_sending_dot_tx__pb2.MsgWithdrawFromSubaccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendFromModuleToAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dydxprotocol.sending.Msg/SendFromModuleToAccount',
            dydxprotocol_dot_sending_dot_transfer__pb2.MsgSendFromModuleToAccount.SerializeToString,
            dydxprotocol_dot_sending_dot_tx__pb2.MsgSendFromModuleToAccountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/daemons/liquidation/liquidation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as dydxprotocol_dot_subaccounts_dot_subaccount__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2dydxprotocol/daemons/liquidation/liquidation.proto\x12 dydxprotocol.daemons.liquidation\x1a\x14gogoproto/gogo.proto\x1a)dydxprotocol/subaccounts/subaccount.proto\"c\n\x1bLiquidateSubaccountsRequest\x12\x44\n\x0esubaccount_ids\x18\x01 \x03(\x0b\x32&.dydxprotocol.subaccounts.SubaccountIdB\x04\xc8\xde\x1f\x00\"\x1e\n\x1cLiquidateSubaccountsResponse2\xac\x01\n\x12LiquidationService\x12\x95\x01\n\x14LiquidateSubaccounts\x12=.dydxprotocol.daemons.liquidation.LiquidateSubaccountsRequest\x1a>.dydxprotocol.daemons.liquidation.LiquidateSubaccountsResponseBCZAgithub.com/dydxprotocol/v4-chain/protocol/daemons/liquidation/apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.daemons.liquidation.liquidation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZAgithub.com/dydxprotocol/v4-chain/protocol/daemons/liquidation/api'
  _LIQUIDATESUBACCOUNTSREQUEST.fields_by_name['subaccount_ids']._options = None
  _LIQUIDATESUBACCOUNTSREQUEST.fields_by_name['subaccount_ids']._serialized_options = b'\310\336\037\000'
  _globals['_LIQUIDATESUBACCOUNTSREQUEST']._serialized_start=153
  _globals['_LIQUIDATESUBACCOUNTSREQUEST']._serialized_end=252
  _globals['_LIQUIDATESUBACCOUNTSRESPONSE']._serialized_start=254
  _globals['_LIQUIDATESUBACCOUNTSRESPONSE']._serialized_end=284
  _globals['_LIQUIDATIONSERVICE']._serialized_start=287
  _globals['_LIQUIDATIONSERVICE']._serialized_end=459
# @@protoc_insertion_point(module_scope)
